"""Tests for functions"""

import yaml

import akshara.varnakaarya as vk


def test_get_vinyaasa():
    """Test get_vinyaasa() function"""

    fname = "tests/sample_texts.yml"

    with open(fname, "r", encoding="utf-8") as file:
        data_dict = yaml.safe_load(file)

    data_dict = data_dict["vinyaasa"]

    for key in data_dict.keys():
        assert ",".join(vk.get_vinyaasa(key)) == data_dict[key]


def test_get_shabda():
    """Test get_vinyaasa() function"""

    fname = "tests/sample_texts.yml"

    with open(fname, "r", encoding="utf-8") as file:
        data_dict = yaml.safe_load(file)

    data_dict = data_dict["vinyaasa"]

    for key in data_dict.keys():
        assert vk.get_shabda(vk.get_vinyaasa(key)) == key



"""Contructs a list of varnas with all properties"""
import os

import yaml


def write_csv(parts: list, filename: str):
    """Writes properties of a single varna to a csv file

    Args:
        parts (list): List of components to be written
        filename (str): Filename of the output file
    """

    with open(filename, "a", encoding="utf-8") as file:
        for index, part in enumerate(parts):
            file.write(part)
            if index == len(parts) - 1:
                file.write("\n")
            else:
                file.write(",")


def create_moola(data_dict: dict, moola_fname: str):
    """Creates moola varna table

    Args:
        data_dict (dict): Data dictionary containing all information
        moola_fname (str): Output filename
    """

    os.remove(moola_fname)

    for data_key in data_dict.keys():
        if "आभ्यन्तरप्रयत्नः" not in data_dict[data_key].keys():
            data_dict[data_key]["आभ्यन्तरप्रयत्नः"] = "-"

        if "बाह्यप्रयत्नः" not in data_dict[data_key].keys():
            data_dict[data_key]["बाह्यप्रयत्नः"] = "-"

        if "कालः" not in data_dict[data_key].keys():
            data_dict[data_key]["कालः"] = "-"

        if isinstance(data_dict[data_key]["उच्चारणस्थानम्"], list):
            data_dict[data_key]["उच्चारणस्थानम्"] = "+".join(
                data_dict[data_key]["उच्चारणस्थानम्"]
            )

        if isinstance(data_dict[data_key]["बाह्यप्रयत्नः"], list):
            data_dict[data_key]["बाह्यप्रयत्नः"] = "+".join(
                data_dict[data_key]["बाह्यप्रयत्नः"]
            )

        parts = [
            data_key,
            data_dict[data_key]["भेदः"],
            data_dict[data_key]["उच्चारणस्थानम्"],
            data_dict[data_key]["आभ्यन्तरप्रयत्नः"],
            data_dict[data_key]["बाह्यप्रयत्नः"],
            data_dict[data_key]["कालः"],
        ]

        write_csv(parts, moola_fname)


def handle_anunaasika(data: dict, naasika: str) -> dict:
    """Modifies data according to anunaasika

    Args:
        data (dict): Original data

    Returns:
        dict: Modified data
    """

    if naasika == "ँ":
        data["नासिकभेदः"] = "अनुनासिकः"
        data["उच्चारणस्थानम्"] = data["उच्चारणस्थानम्"] + "+" + "नासिका"

    return data


def get_svara_chinha(svara_bheda: str) -> str:
    """Returns svarachinha according to svarabheda

    Args:
        svara_bheda (str): Svarabheda

    Returns:
        str: Svarachinha
    """

    if svara_bheda == "अनुदात्तः":
        chinha = "॒"
    elif svara_bheda == "स्वरितः":
        chinha = "॑"
    else:
        chinha = ""

    return chinha


def create_vistrita(data_dict, vistrita_fname):
    """Creates vistrita varna table

    Args:
        data_dict (dict): Data dictionary containing all information
        moola_fname (str): Output filename
    """

    os.remove(vistrita_fname)

    for data_key in data_dict.keys():
        data_dict[data_key]["नासिकभेदः"] = "निरनुनासिकः"

        if data_dict[data_key]["भेदः"] == "स्वरः":
            for naasika in ["", "ँ"]:
                data_dict[data_key] = handle_anunaasika(data_dict[data_key], naasika)

                for baahyaprayatna in ["उदात्तः", "अनुदात्तः", "स्वरितः"]:
                    data_dict[data_key]["बाह्यप्रयत्नः"] = baahyaprayatna

                    chinha = get_svara_chinha(baahyaprayatna)

                    temp = (
                        data_key + naasika + chinha
                        if len(data_key) == 1
                        else data_key[0] + naasika + chinha + data_key[1]
                    )

                    parts = [
                        temp,
                        data_dict[data_key]["भेदः"],
                        data_dict[data_key]["उच्चारणस्थानम्"],
                        data_dict[data_key]["आभ्यन्तरप्रयत्नः"],
                        data_dict[data_key]["बाह्यप्रयत्नः"],
                        data_dict[data_key]["कालः"],
                        data_dict[data_key]["नासिकभेदः"],
                    ]

                    write_csv(parts, vistrita_fname)

        elif data_key in ["य्", "ल्", "व्"]:
            for naasika in ["", "ँ"]:
                data_dict[data_key] = handle_anunaasika(data_dict[data_key], naasika)

                temp = data_key + naasika

                parts = [
                    temp,
                    data_dict[data_key]["भेदः"],
                    data_dict[data_key]["उच्चारणस्थानम्"],
                    data_dict[data_key]["आभ्यन्तरप्रयत्नः"],
                    data_dict[data_key]["बाह्यप्रयत्नः"],
                    data_dict[data_key]["कालः"],
                    data_dict[data_key]["नासिकभेदः"],
                ]

                write_csv(parts, vistrita_fname)

        else:
            if "आभ्यन्तरप्रयत्नः" not in data_dict[data_key].keys():
                data_dict[data_key]["आभ्यन्तरप्रयत्नः"] = "-"

            if "बाह्यप्रयत्नः" not in data_dict[data_key].keys():
                data_dict[data_key]["बाह्यप्रयत्नः"] = "-"

            if "कालः" not in data_dict[data_key].keys():
                data_dict[data_key]["कालः"] = "-"

            if "+" in data_dict[data_key]["उच्चारणस्थानम्"]:
                if "नासिका" in data_dict[data_key]["उच्चारणस्थानम्"]:
                    data_dict[data_key]["नासिकभेदः"] = "अनुनासिकः"

            parts = [
                data_key,
                data_dict[data_key]["भेदः"],
                data_dict[data_key]["उच्चारणस्थानम्"],
                data_dict[data_key]["आभ्यन्तरप्रयत्नः"],
                data_dict[data_key]["बाह्यप्रयत्नः"],
                data_dict[data_key]["कालः"],
                data_dict[data_key]["नासिकभेदः"],
            ]

            write_csv(parts, vistrita_fname)


def create_varna_table(
    input_file="resources/varna.yml",
    moola="resources/moola.csv",
    laukika="resources/laukika.csv",
    vistrita="resources/vistrita.csv",
    latest="resources/latest.csv",
):
    """Creates varna tables

    Args:
        input (str, optional): Input file for varnas (yaml). Defaults to "resources/varna.yml".
        moola (str, optional): Output file for moola. Defaults to "resources/moola.csv".
        laukika (str, optional): Output file for laukika. Defaults to "resources/laukika.csv".
        vistrita (str, optional): Output file for vistrita. Defaults to "resources/vistrita.csv".
        latest (str, optional): Output file for latest. Defaults to "resources/latest.csv".
    """

    path = f"{str(os.path.dirname(__file__))}"
    input_fname = f"{path}/{input_file}"
    moola_fname = f"{path}/{moola}"
    laukika_fname = f"{path}/{laukika}"
    vistrita_fname = f"{path}/{vistrita}"
    latest_fname = f"{path}/{latest}"

    with open(input_fname, "r", encoding="utf-8") as file:
        data_dict = yaml.safe_load(file)

    create_moola(data_dict, moola_fname)
    create_vistrita(data_dict, vistrita_fname)

    with open(vistrita_fname, "r", encoding="utf-8") as file:
        lines = file.readlines()

    with open(laukika_fname, "w", encoding="utf-8") as file:
        for line in lines:
            if "॒" not in line and "॑" not in line and "यमः" not in line:
                file.write(line)

    with open(latest_fname, "w", encoding="utf-8") as file:
        for line in lines:
            if "॒" not in line and "॑" not in line and "यमः" not in line:
                file.write(line.replace("संवृतः", "विवृतः"))


if __name__ == "__main__":
    create_varna_table()



"""Handles all operations on varnas"""

import sys

from akshara.varna import Varnamaalaa

vn = Varnamaalaa()


def check_vinyaasa(vinyaasa: list) -> None:
    """Checks is a vinyaasaa contains illegal characters

    Args:
        vinyaasa (list): Vinyaasa to be analysed
    """

    for symbol in vinyaasa:
        assert (
            symbol
            in vn.all_svaras
            + vn.all_vyanjanas
            + vn.avasaana
            + vn.sankhyaa
            + vn.ayogavaaha
            + ["ऽ", "\n", "(", ")", "{", "}", "[", "]"]
        ), f"Illegal varna {symbol} found in vinyaasaa {vinyaasa}"


def maarjaka(sentence: str) -> str:
    """Cleans up a string

    Args:
        sentence (str): String to be cleaned

    Returns:
        str: Clean string
    """

    sentence = sentence.rstrip("\n")

    return sentence


def count_svaras(vinyaasa: list) -> int:
    """Counts the number of svaras

    Args:
        vinyaasa (list): Vinyaasa of a string

    Returns:
        int: Number of svaras
    """

    return sum(1 for x in get_vinyaasa(vinyaasa) if x in vn.svara)


def count_vyanjanas(vinyaasa: list) -> int:
    """Counts the number of vyanjanas

    Args:
        vinyaasa (list | str): Vinyaasa of a string

    Returns:
        int: Number of vyanjanas
    """

    return sum(1 for x in get_vinyaasa(vinyaasa) if x in vn.vyanjana)


def count_ayogavaahas(vinyaasa: list) -> int:
    """Counts the number of ayogavaahas

    Args:
        vinyaasa (list | str): Vinyaasa of a string

    Returns:
        int: Number of ayogavaahas
    """

    return sum(1 for x in get_vinyaasa(vinyaasa) if x in vn.ayogavaaha)


def count_varnas(vinyaasa: list) -> int:
    """Counts the number of varnas

    Args:
        vinyaasa (list | str): Vinyaasa of a string

    Returns:
        int: Number of varnas
    """

    return (
        count_svaras(vinyaasa) + count_vyanjanas(vinyaasa) + count_ayogavaahas(vinyaasa)
    )


def count_vaakyas(vinyaasa: list) -> int:
    """Counts the number of vaakyas

    Args:
        vinyaasa (list): Vinyaasa of a string

    Returns:
        int: Number of vaakyas
    """

    return sum(1 for x in vinyaasa if x in ["।", "॥"])


def break_paada(vinyaasa: list) -> list:
    """Breaks a line into two equal paadas

    Args:
        vinyaasa (list): Vinyaasa of the string to be broken

    Returns:
        list: List containing two resultant vinyaasas
    """

    i = 0

    while count_svaras(vinyaasa[0:i]) < count_svaras(vinyaasa) / 2.0:
        i += 1

    if vinyaasa[i] in ["ः", "ं"] or vinyaasa[i] not in [" "]:
        i += 1

    return [vinyaasa[0:i], vinyaasa[i:]]


def add_akaara(shabda: str, index: int, vinyaasa: list) -> list:
    """Decides on the type of akaara (anunaasika or not) to be added in the vinyaasa and adds it

    Args:
        shabda (str): String in consideration
        index (int): Location in the string which is being considered
        vinyaasa (list): Current state of the vinyaasa

    Returns:
        list: Updated vinyaasa
    """

    if index + 1 < len(shabda):
        if (
            shabda[index + 1] in vn.vyanjana_with_akaara
            or shabda[index + 1] in vn.avasaana
            or shabda[index + 1] in ["ः", "ं", "३", "(", ")", "{", "}", "[", "]"]
        ):
            vinyaasa.append("अ")

        if shabda[index + 1] in ["ँ"]:
            vinyaasa.append("अँ")
    else:
        vinyaasa.append("अ")

    return vinyaasa


def combine_pluta(vinyaasa: list) -> list:
    """Combines all pluta markings with their svaras

    Args:
        vinyaasa (list): Vinyaasa in consideration

    Returns:
        list: Modified vinyaasa
    """

    while "३" in vinyaasa:
        index = vinyaasa.index("३")
        if vinyaasa[index - 1] in vn.svara + vn.anunaasika_svara:
            vinyaasa[index - 1] += "३"
            del vinyaasa[index]
        else:
            vinyaasa[index] = "a"

    vinyaasa = ["३" if x == "a" else x for x in vinyaasa]

    return vinyaasa


def split_pluta(vinyaasa: list) -> list:
    """Splits all pluta markings

    Args:
        vinyaasa (list): Vinyaasa in consideration

    Returns:
        list: Modified vinyaasa
    """

    index = 0

    while index < len(vinyaasa):
        if "३" not in vinyaasa[index]:
            index += 1
        else:
            vinyaasa[index] = vinyaasa[index][:-1]
            vinyaasa.insert(index + 1, "३")
            index += 2

    return vinyaasa


def get_vinyaasa(shabda: str) -> list:
    """Returns the vinyaasa (spelling) of a string

    Args:
        shabda (str): String to be spelled

    Returns:
        str: Spelling of the string
    """

    shabda = maarjaka(shabda)
    vinyaasa = []

    for index, element in enumerate(shabda):
        if element in vn.svara:
            vinyaasa.append(element)
        elif element in vn.vyanjana_with_akaara:
            if (
                len(shabda) > index + 2
                and shabda[index + 1] == "्"
                and shabda[index + 2] == "ँ"
            ):
                vinyaasa.append(element + "्" + "ँ")
            else:
                vinyaasa.append(element + "्")
            vinyaasa = add_akaara(shabda, index, vinyaasa)
        elif element in vn.maatraa:
            if index + 1 < len(shabda):
                if shabda[index + 1] in ["ँ"]:
                    vinyaasa.append(vn.maatraa_to_svara[element] + "ँ")
                else:
                    vinyaasa.append(vn.maatraa_to_svara[element])
            else:
                vinyaasa.append(vn.maatraa_to_svara[element])
        elif element in ["्", "ँ"]:
            pass
        else:
            vinyaasa.append(element)

    check_vinyaasa(vinyaasa)

    vinyaasa = combine_pluta(vinyaasa)

    return vinyaasa


def get_shabda(vinyaasa: list) -> str:
    """Reconstructs a string from a vinyaasa (spelling)

    Args:
        vinyaasa (list): Spelling of the string

    Returns:
        str: Reconstructed string
    """

    vinyaasa = split_pluta(vinyaasa)

    shabda = ""

    for index, varna in enumerate(vinyaasa):
        if index == 0 and varna in vn.svara:
            symbol = varna
        elif varna in vn.svara and (
            vinyaasa[index - 1] in vn.svara
            or vinyaasa[index - 1] in [" ", "।", "॥", "(", ")", "{", "}", "[", "]"]
        ):
            symbol = varna
        elif varna in vn.vyanjana and index + 1 < len(vinyaasa):
            if (
                vinyaasa[index + 1] in vn.svara
                or vinyaasa[index + 1] in vn.anunaasika_svara
            ):
                symbol = varna[0]
            else:
                symbol = varna
        elif varna == "अ":
            symbol = ""
        elif varna == "अँ":
            symbol = "ँ"
        elif varna in vn.svara and vinyaasa[index - 1] in vn.vyanjana:
            symbol = vn.svara_to_maatraa[varna]
        elif varna in vn.anunaasika_svara:
            symbol = vn.svara_to_maatraa[varna[0]] + "ँ"
        else:
            symbol = varna

        shabda = shabda + symbol

    return shabda


def get_sankhyaa(roman: str) -> str:
    """Converts romal numerals to devanaagari

    Args:
        s (str): Roman number in string form

    Returns:
        str: Devanaagari number in string form
    """

    devanaagari = ""
    roman = str(roman)

    for digit in roman:
        if digit == ".":
            devanaagari += digit
        elif int(digit) < 0 or int(digit) > 9:
            print(f"{digit} is Not a digit")
            sys.exit()
        else:
            devanaagari += vn.sankhyaa[int(digit)]

    return devanaagari


def get_akshara(word: str) -> list:
    """Returns the akshara (syllable) of a string

    Args:
        word (str): String to be syllabified

    Returns:
        list: Syllables of the string
    """

    vinyaasa = get_vinyaasa(word)

    index_svara = [
        i for i, x in enumerate(vinyaasa) if x in vn.svara or x in vn.anunaasika_svara
    ]

    akshara = []
    start = 0
    for i in index_svara:
        akshara.append(get_shabda(vinyaasa[start : i + 1]))
        start = i + 1

    print(index_svara)

    if index_svara and index_svara[-1] != len(vinyaasa) - 1:

        if len(akshara) == 1:
            akshara = [get_shabda(vinyaasa)]

        else:
            akshara[-1] = get_shabda(vinyaasa[index_svara[-2] + 1 :])

    return akshara



"""Defines basic alphabet for sanskrit"""

import os

import yaml


class Varna:
    """Class describing a single varna"""

    def __init__(self, line: str) -> None:
        parts = line.split(",")
        self.roopa = parts[0]
        self.bheda = parts[1]
        self.sthaana = parts[2]
        self.aabhyantara = parts[3]
        self.baahya = parts[4]
        self.kaala = parts[5]
        self.anunaasika = parts[6] == "अनुनासिकः\n"

    def get_roopa(self) -> str:
        """Returns the letter (roopa)"""
        return self.roopa

    def describe(self) -> None:
        """Prints description of the varna"""
        print(f"{self.roopa}, {self.sthaana}, {self.aabhyantara}")

    def is_svara(self) -> bool:
        """Checks if varna is svara"""
        return self.bheda == "स्वरः"

    def is_vyanjana(self) -> bool:
        """Checks if varna is vyanjana"""
        return self.bheda == "व्यञ्जनम्"

    def is_ayogavaaha(self) -> bool:
        """Checks if varna is ayogavaaha"""
        return self.bheda == "अयोगवाहः"

    def is_anunaasika(self) -> bool:
        """Checks if varna is anunaasika"""
        return self.anunaasika


class Varnamaalaa:
    """Class describing the varnamaalaa"""

    def __init__(
        self,
        varna_file_path="resources/latest.csv",
        vividha_file_path="resources/vividha.yml",
    ) -> None:
        path = f"{str(os.path.dirname(__file__))}"
        varna_file_path = f"{path}/{varna_file_path}"
        vividha_file_path = f"{path}/{vividha_file_path}"
        with open(varna_file_path, "r", encoding="utf-8") as file:
            lines = file.readlines()

        with open(vividha_file_path, "r", encoding="utf-8") as file:
            data = yaml.safe_load(file)

        self.varnamaalaa = list(Varna(line) for line in lines)
        self.varnas = [x.get_roopa() for x in self.varnamaalaa]
        self.all_svaras = [x.get_roopa() for x in self.varnamaalaa if x.is_svara()]
        self.all_vyanjanas = [
            x.get_roopa() for x in self.varnamaalaa if x.is_vyanjana()
        ]
        self.svara = [
            x.get_roopa()
            for x in self.varnamaalaa
            if x.is_svara() and x.anunaasika is False and x.kaala != "प्लुतः"
        ]
        self.anunaasika_svara = [
            x.get_roopa()
            for x in self.varnamaalaa
            if x.is_svara() and x.anunaasika is True and x.kaala != "प्लुतः"
        ]
        self.vyanjana = [x.get_roopa() for x in self.varnamaalaa if x.is_vyanjana()]
        self.vyanjana_with_akaara = [x[0] for x in self.vyanjana]
        self.ayogavaaha = [x.get_roopa() for x in self.varnamaalaa if x.is_ayogavaaha()]

        self.maaheshwara_sutra = data["maaheshwara_sutra"]
        self.maatraa = data["maatraa"]
        self.sankhyaa = data["sankhyaa"]
        self.avasaana = [" ", "।", "॥", "-"]

        self.maatraa_to_svara = dict(zip(self.maatraa, self.svara[1:]))
        self.svara_to_maatraa = dict(zip(self.svara[1:], self.maatraa))

    def get_savarna(self, varna: str) -> list:
        """Returns savarnas of a varna

        Args:
            varna (str): Input varna

        Returns:
            list: List of savarnas
        """

        ref = list(x for x in self.varnamaalaa if x.get_roopa() == varna)

        assert len(ref) == 1, f"Expected 1 and only 1 varna to find savarnas. Got {ref}"

        ref = ref[0]

        test1 = list(
            x.get_roopa()
            for x in self.varnamaalaa
            if [x.bheda, x.sthaana, x.aabhyantara]
            == [ref.bheda, ref.sthaana, ref.aabhyantara]
        )

        test2 = list(
            x.get_roopa()
            for x in self.varnamaalaa
            if [x.bheda, x.sthaana, x.aabhyantara]
            == [ref.bheda, ref.sthaana + "+नासिका", ref.aabhyantara]
        )

        if "ऋ" in test1:
            test1.extend(["ऌ", "ऌ३"])

        if "ऋँ" in test2:
            test2.extend(["ऌँ", "ऌँ३"])

        return test1 + test2

    def get_varna(self, string: str) -> Varna:
        """Converts a varna character to Varna object

        Args:
            string (str): Varna character

        Returns:
            Varna: Varna object
        """
        varna = list(x for x in self.varnamaalaa if x.get_roopa() == string)

        assert (
            len(varna) == 1
        ), f"Expected 1 and only 1 varna to varna properties. Got {varna}"

        return varna[0]

    def expand(self, code: str) -> list:
        """Pratyaahaaragrahana or savarnagrahana

        Args:
            code (str): Pratyaahaara or savarnagraahi

        Returns:
            list: List of varna
        """

        assert len(code) <= 3, f"Varnasanketa {code} is too long"

        if (
            len(code) == 2
            and code[1] == self.maatraa[3]
            and self.get_varna(code[0] + "्").is_vyanjana()
        ):
            return self.get_savarna(code[0] + "्")
        if len(code) == 3 and code[1] == "त" and code[2] == "्":
            return [code[0], code[0] + "ँ"]
        if len(code) == 1 and self.get_varna(code[0]).is_svara():
            return self.get_savarna(code[0])
        if len(code) == 3 and code[2] == "्":
            start = code[0]
            stop = code[1] + code[2]

            i = self.maaheshwara_sutra.index(start)
            j = self.maaheshwara_sutra.index(stop)

            section = self.maaheshwara_sutra[i:j]

            it_letter = [
                x for x in section if len(x) == 2 and self.get_varna(x).is_vyanjana()
            ]

            for letter in it_letter:
                section.remove(letter)

            section = [x if x in self.varnas else x + "्" for x in section]

            extension = [
                self.get_savarna(x) for x in section if self.get_varna(x).is_svara()
            ]

            extension = [item for sublist in extension for item in sublist]

            section.extend(extension)

            return section

        return []


def read_table(filename="latest.csv", directory="resources") -> list:
    """Read varna table

    Args:
        filename (str, optional): Filename of resource table. Defaults to 'latest.csv'.
        directory (str, optional): Resource directory. Defaults to 'resources'.

    Returns:
        list: List of lines read
    """

    path = f"{str(os.path.dirname(__file__))}/{directory}/{filename}"

    with open(path, "r", encoding="utf-8") as file:
        lines = file.readlines()

    return list(lines)



"""Module to perform sutra related tasks"""

from dataclasses import dataclass
import json
import os


@dataclass
class Sutra:
    """Class to represent a sutra"""

    adhyaya: int
    paada: int
    number: int
    text: str

    def __repr__(self):
        return f"{self.adhyaya}.{self.paada}.{self.number}: {self.text}"

    def __post_init__(self):
        if not isinstance(self.adhyaya, int):
            raise ValueError("Adhyaya should be an integer")
        if not isinstance(self.paada, int):
            raise ValueError("Paada should be an integer")
        if not isinstance(self.number, int):
            raise ValueError("Number should be an integer")
        if not isinstance(self.text, str):
            raise ValueError("Text should be a string")

        if self.adhyaya < 1 or self.adhyaya > 8:
            raise ValueError("Adhyaya should be between 1 and 8")

        if self.paada < 1 or self.paada > 4:
            raise ValueError("Paada should be between 1 and 4")

        if self.number < 1:
            raise ValueError("Number should be a positive integer")


def create_sutra_list(filename: os.PathLike):
    """Create a list of Sutra objects from a file"""

    with open(filename, "r", encoding="utf-8") as file:
        lines = json.load(file)

    return list(
        Sutra(int(data["a"]), int(data["p"]), int(data["n"]), data["s"])
        for data in lines["data"]
    )


def main():
    """Main function"""

    print(create_sutra_list("akshara/sutra/sutra.json"))


if __name__ == "__main__":

    main()



"""Installs the package"""

from pathlib import Path

from setuptools import find_packages, setup

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="akshara",
    version="1.1.1",
    author="Arindam Saha",
    author_email="arindamsaha1507@gmail.com",
    url="https://github.com/arindamsaha1507/akshara",
    description="A project to help spelling in Sanskrit (Devanaagari)",
    long_description_content_type="text/markdown",
    long_description=long_description,
    license="GNU GENERAL PUBLIC LICENSE",
    packages=find_packages(exclude=["test"]),
    install_requires=["pyyaml"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Linguistic",
    ],
    include_package_data=True,
)
